@@ -69,8 +69,7 @@ class ConverterNode(Node):
 
                 for model in models:
                     if model['version']:
-                        # and not self.converter.target_format in model['formats']:
-                        if self.converter.source_format in model['formats']:
+                        if self.converter.source_format in model['formats'] and not self.converter.target_format in model['formats']:
                             model_information = ModelInformation(
                                 organization=organization_id, project=project_id, model_id=model['id'], project_categories=project_categories, version=model['version'])
                             await self.convert_model(model_information)
