@@ -1,3 +1,4 @@
+from learning_loop_node.context import Context
 from typing import List, Optional
 from learning_loop_node.node import Node
 from learning_loop_node.trainer.trainer import Trainer
@@ -15,13 +16,13 @@ async def assert_upload_model(file_paths: Optional[List[str]] = None) -> str:
 
     for path in file_paths:
         data.add_field('files',  open(path, 'rb'))
-    async with loop.LoopHttp().post('api/zauberzeug/projects/pytest/models/mocked', data) as response:
+    async with loop.post('api/zauberzeug/projects/pytest/models/mocked', data) as response:
         assert response.status == 200
         return (await response.json())['id']
 
 
 def create_needed_folders(training_uuid='some_uuid'):
-    project_folder = Node.create_project_folder('zauberzeug', 'pytest')
+    project_folder = Node.create_project_folder(Context(organization='zauberzeug', project='pytest'))
     image_folder = Trainer.create_image_folder(project_folder)
     training_folder = Trainer.create_training_folder(project_folder, training_uuid)
     return project_folder, image_folder, training_folder
