@@ -17,15 +17,14 @@ class Trainer(BaseModel):
     capability: Capability
     model_format: str
 
-    async def begin_training(self, organization: str, project: str, source_model: dict) -> None:
-        context = Context(organization=organization, project=project)
+    async def begin_training(self, context: Context, source_model: dict) -> None:
         downloader = DownloaderFactory.create(context, self.capability)
 
         self.training = Trainer.generate_training(context, source_model)
         self.training.data = await downloader.download_data(self.training.images_folder)
 
         await node_helper.download_model(self.training.training_folder,
-                                         organization, project, source_model['id'], self.model_format)
+                                         context, source_model['id'], self.model_format)
 
         await self.start_training()
 
@@ -38,9 +37,9 @@ class Trainer(BaseModel):
     def is_training_alive(self) -> bool:
         raise NotImplementedError()
 
-    async def save_model(self,  organization: str, project: str, model_id) -> None:
+    async def save_model(self,  context:Context, model_id:str) -> None:
         files = self.get_model_files(model_id)
-        await node_helper.upload_model(organization, project, files, model_id, self.model_format)
+        await node_helper.upload_model(context, files, model_id, self.model_format)
 
     def get_model_files(self, model_id) -> List[str]:
         raise NotImplementedError()
@@ -54,7 +53,7 @@ class Trainer(BaseModel):
     @staticmethod
     def generate_training(context: Context, source_model: dict) -> Training:
         training_uuid = str(uuid4())
-        project_folder = Node.create_project_folder(context.organization, context.project)
+        project_folder = Node.create_project_folder(context)
         return Training(
             id=training_uuid,
             base_model=source_model,
