@@ -1,4 +1,5 @@
 import asyncio
+from learning_loop_node.context import Context
 import traceback
 from fastapi_utils.tasks import repeat_every
 from fastapi.encoders import jsonable_encoder
@@ -11,6 +12,7 @@ from learning_loop_node.status import TrainingStatus
 from learning_loop_node.node import Node, State
 import logging
 
+
 class TrainerNode(Node):
     trainer: Trainer
     latest_known_model_id: Union[str, None]
@@ -24,7 +26,7 @@ class TrainerNode(Node):
         @self.sio_client.on('begin_training')
         async def on_begin_training(organization, project, source_model):
             loop = asyncio.get_event_loop()
-            loop.create_task(self.begin_training(organization, project, source_model))
+            loop.create_task(self.begin_training(Context(organization=organization, project=project), source_model))
             return True
 
         @self.sio_client.on('stop_training')
@@ -34,7 +36,7 @@ class TrainerNode(Node):
         @self.sio_client.on('save')
         def on_save(organization, project, model):
             loop = asyncio.get_event_loop()
-            loop.create_task(self.save_model(organization, project, model['id']))
+            loop.create_task(self.save_model(Context(organization=organization, project=project), model['id']))
             return True
 
         @self.on_event("startup")
@@ -43,11 +45,11 @@ class TrainerNode(Node):
             if not self.skip_check_state:
                 await self.check_state()
 
-    async def begin_training(self, organization: str, project: str, source_model: dict):
+    async def begin_training(self, context: Context, source_model: dict):
         self.status.latest_error = None
         await self.update_state(State.Preparing)
         try:
-            await self.trainer.begin_training(organization, project, source_model)
+            await self.trainer.begin_training(context, source_model)
         except Exception as e:
             self.status.latest_error = f'Could not start training: {str(e)})'
             logging.exception(self.status.latest_error)
@@ -72,9 +74,9 @@ class TrainerNode(Node):
         await self.send_status()
         return True
 
-    async def save_model(self, organization, project, model_id):
+    async def save_model(self, context:Context, model_id:str):
         try:
-            await self.trainer.save_model(organization, project, model_id)
+            await self.trainer.save_model(context, model_id)
         except Exception as e:
             traceback.print_exc()
             await self.update_error_msg(f'Could not save model: {str(e)}')
@@ -136,3 +138,8 @@ class TrainerNode(Node):
     async def update_error_msg(self, msg: str) -> None:
         self.status.latest_error = msg
         await self.send_status()
+    
+    async def get_state(self):
+        if self.trainer.is_training_alive():
+            return State.Running
+        return State.Idle
